@@ -23,30 +23,28 @@ def arg_parse(config_file):
     # parser = argparse.ArgumentParser(description='argument parses for upload script.')
     parser.add_argument("--type", type=str, help="radar type")
     parser.add_argument("--version", type=str, help="version name")
-    parser.add_argument("--filepath", type=str, help="file path")
 
     args = parser.parse_args()
     radarType = args.type
     version_name = args.version
-    filepath = args.filepath
 
     if args.check:
         parse_config(config_file)
-        check_upload_file(filepath)
+        check_upload_file(config_file['filepath'])
         exit(0)
     if args.config:
         create_config(config_file)
         exit(0)
     elif args.upload:
         parse_config(config_file)
-        check_upload_file(filepath)
+        check_upload_file(config_file['filepath'])
 
         print("given type: ", radarType)
         print("given version_name: ", version_name)
-        print("given filepath: ", filepath)
+        print("given filepath: ", config_file['filepath'])
 
-        version_dir_to_upload= os.path.join(filepath, version_name)
-        zipped_file_path = os.path.join(filepath, version_name + '.zip')
+        version_dir_to_upload= os.path.join(config_file['filepath'], version_name)
+        zipped_file_path = os.path.join(config_file['filepath'], version_name + '.zip')
 
         print('version_dir_to_upload: ', version_dir_to_upload)
         print('zipped_file_path: ', zipped_file_path)
