@@ -14,7 +14,8 @@ def create_config(config_file):
         config = {
             "robin_email": "your email address",
             "robin_password": "your password",
-            "api_url": "api url"
+            "api_url": "api url",
+            'filepath': 'path to the file you want to upload'
         }
         # create the directory if it doesn't exist
         os.makedirs(os.path.dirname(config_file), exist_ok=True)
