@@ -18,6 +18,9 @@ def parse_config(config_file):
                 if not validators.url(config['api_url']):
                     print("api_url is not a valid URL")
                     exit(1)
+                if type(config['filepath']) is not str:
+                    print("filepath is not a string")
+                    exit(1)
                 return config
             except yaml.YAMLError as exc:
                 print(exc)
