@@ -1,32 +1,15 @@
 import os
 import requests
 import json
-import yaml
 from .get_bearer_token import get_bearer_token
 
-radarType = ''
-# version_name = ''
-# bearer_token = ''
-
-home_dir = os.path.expanduser("~")
-config_file = home_dir + "/.config/robin/config.yaml"
+# get api url from config file
 
 
-#********** Credentials to login from config.yml **********
-with open("config.yml", "r") as file:
-    config_file = yaml.safe_load(file)
-
-robin_email = config_file['robin_email']
-robin_password = config_file['robin_password']
-api_url = config_file['api_url']
-
-def push_software(fpath, radarType, version_name):
+def push_software(config_file, fpath, radarType, version_name):
     print('Getting the bearer token...')
-    # print('PS robin_email: ', robin_email)
-    # print('PS robin_password: ', robin_password)
-    # print('PS api_url: ', api_url)
-
-    bearer_token = get_bearer_token()
+    api_url = config_file['api_url']
+    bearer_token = get_bearer_token(config_file)
     headers = {
         'Authorization': 'Bearer ' + bearer_token,
     }
